==> 4.0.0-ISS-GKLM-FP0005-AIX.tar.gz: agent/DB2SklmCmdExec.sh <==
#!/bin/sh
#set -x
#
# Licensed Materials-Property of IBM
# (C)Copyright IBM Corp 2008
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
# 
# The script is to be called from the IBM Tivoli Key Life Cycle Manager 
# Installer
#  
# arg1 -  dbname  -  database name
# arg2 -  dbinstance_owner_home - home of the instance owner  
#  Note:  The script 
#	        must be run on the same machine where DB2 server is installed.
#		does do not parameter validation
#
#------------------------------------------------------------------------------

PROFILE_HOME=$1
DB2_USER_NAME=$2
CMD=$3
CMD_HOME=$4

#temporary return code
dbrc=0

if [ $# -lt 3 ]; then
echo "Usage: DB2SklmCmdExec.sh <dbinstallhomeDir> <db2 username> <commandToExecute> [commandHomeDir]"
    exit 2
fi


##################################################################
echo "---------------------------------------------------------------------------------------------------"
echo Started executing DB2SklmCmdExec.sh
echo "---------------------------------------------------------------------------------------------------"

CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" = "." ]; then
   CURRENT_DIR=`pwd`
fi

# set instance profile path to source profile of local instance
#source $PROFILE_HOME/db2profile
username=$(whoami)
echo user : $username
echo . $PROFILE_HOME/sqllib/db2profile 
. $PROFILE_HOME/sqllib/db2profile
echo Db2 profile loaded.
echo Performing command operation.
if [ "$username" != "$DB2_USER_NAME" ]; then
	echo su - $DB2_USER_NAME -c "$CMD"
	su - $DB2_USER_NAME -c "$CMD"
	dbrc=$?
else
	echo $CMD
	$CMD
	dbrc=$?	
fi
if [ $dbrc -eq 0 ]; then
	echo $CMD successful.
fi
exit $dbrc

==> 4.1.0-ISS-GKLM-FP0005-AIX.tar.gz: agent/DB2SklmCmdExec.sh <==
#!/bin/sh
#set -x
#
# Licensed Materials-Property of IBM
# (C)Copyright IBM Corp 2008
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
# 
# The script is to be called from the IBM Tivoli Key Life Cycle Manager 
# Installer
#  
# arg1 -  dbname  -  database name
# arg2 -  dbinstance_owner_home - home of the instance owner  
#  Note:  The script 
#	        must be run on the same machine where DB2 server is installed.
#		does do not parameter validation
#
#------------------------------------------------------------------------------

PROFILE_HOME=$1
DB2_USER_NAME=$2
CMD=$3
CMD_HOME=$4
DB_PRINCIPAL=$5

#temporary return code
dbrc=0

if [ $# -lt 3 ]; then
echo "Usage: DB2SklmCmdExec.sh <dbinstallhomeDir> <db2 username> <commandToExecute> [commandHomeDir]"
    exit 2
fi


##################################################################
echo "---------------------------------------------------------------------------------------------------"
echo Started executing DB2SklmCmdExec.sh
echo "---------------------------------------------------------------------------------------------------"

CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" = "." ]; then
   CURRENT_DIR=`pwd`
fi

# set instance profile path to source profile of local instance
#source $PROFILE_HOME/db2profile
username=$(whoami)
echo user : $username
echo . $PROFILE_HOME/sqllib/db2profile 
. $PROFILE_HOME/sqllib/db2profile
echo Db2 profile loaded.

OS=`uname`

if [ ! -z ${DB_PRINCIPAL} ]; then 
    echo Getting kerberos ticket 
    kinit_path=$(which kinit)
    if [ "${OS}" == "Linux" ]
    then
        . ~/.bash_profile
    else
        . ~/.profile
    fi
    "$kinit_path" -k -t $KRB5_KTNAME $DB_PRINCIPAL      
fi

echo Performing command operation.
if [ "$username" != "$DB2_USER_NAME" ]; then
	echo su $DB2_USER_NAME -c "$CMD"
	su $DB2_USER_NAME -c "$CMD"
	dbrc=$?
else
	echo $CMD
	$CMD
	dbrc=$?	
fi
if [ $dbrc -eq 0 ]; then
	echo $CMD successful.
fi
exit $dbrc
